Package 'codemeta'

Title: A Smaller 'codemetar' Package
Description: The 'Codemeta' Project defines a 'JSON-LD' format for describing software metadata, as detailed at <https://codemeta.github.io>. This package provides core utilities to generate this metadata with a minimum of dependencies.
Authors: Carl Boettiger [aut, cre, cph] (ORCID: <https://orcid.org/0000-0002-1642-628X>), Maƫlle Salmon [ctb, aut] (ORCID: <https://orcid.org/0000-0002-2815-0399>), Katrin Leinweber [ctb] (ORCID: <https://orcid.org/0000-0001-5135-5758>), Noam Ross [ctb] (ORCID: <https://orcid.org/0000-0002-2136-0000>), Arfon Smith [ctb], Jeroen Ooms [ctb] (ORCID: <https://orcid.org/0000-0002-4035-0289>), Sebastian Meyer [ctb] (ORCID: <https://orcid.org/0000-0002-1791-9449>), Michael Rustler [ctb] (ORCID: <https://orcid.org/0000-0003-0647-7726>), Hauke Sonnenberg [ctb] (ORCID: <https://orcid.org/0000-0001-9134-2871>), Sebastian Kreutzer [ctb] (ORCID: <https://orcid.org/0000-0002-0734-2199>), rOpenSci [fnd] (https://ropensci.org/)
Maintainer: Carl Boettiger <[email protected]>
License: GPL-3
Version: 0.1.1
Built: 2026-05-19 05:52:50 UTC
Source: https://github.com/cboettig/codemeta

Help Index


write_codemeta

Description

write_codemeta

Usage

write_codemeta(
  path = ".",
  id = NULL,
  file = "codemeta.json",
  verbose = getOption("verbose", FALSE)
)

Arguments

path

path to the package root

id

identifier for the package (e.g. a DOI, as URL)

file

output file location, should be called codemeta.json.

verbose

Whether to print messages indicating the progress of internet downloads.

Value

a codemeta list object (invisbly) and write out the codemeta.json file

Examples

# 'path' and 'out' here are for illustrative use only.
 # typical use in a package is simply `wite_codemeta()` with no arguments

 path <- system.file("", package="codemeta")
 out <- tempfile(fileext =".json")
 write_codemeta(path, file = out)